pub struct AcpClient {
pub initialize_response: InitializeResponse,
pub event_rx: UnboundedReceiver<AcpEvent>,
pub handle: AcpClientHandle,
}Expand description
An initialized ACP connection that can create and manage multiple sessions.
Fields
initialize_response: InitializeResponseevent_rx: UnboundedReceiver<AcpEvent>handle: AcpClientHandleImplementations
Sourceimpl AcpClient
impl AcpClient
Sourcepub fn agent_name(&self) -> String
pub fn agent_name(&self) -> String
The agent’s display title, falling back to its implementation name.
pub fn prompt_capabilities(&self) -> &PromptCapabilities
pub fn session_capabilities(&self) -> &SessionCapabilities
pub fn auth_methods(&self) -> &[AuthMethod]