pub struct AcpClientHandle { /* private fields */ }Implementations
Sourceimpl AcpClientHandle
impl AcpClientHandle
Sourcepub async fn disconnect(&self)
pub async fn disconnect(&self)
Stop this connection and wait for it to close without sending session/cancel or session/close.
pub fn prompt( &self, request: PromptRequest, ) -> impl Future<Output = Result<PromptResponse, AcpClientError>> + Send + use<>
pub fn new_session( &self, request: NewSessionRequest, ) -> impl Future<Output = Result<NewSessionResponse, AcpClientError>> + Send + use<>
Sourcepub fn request<R: JsonRpcRequest>(
&self,
request: R,
) -> impl Future<Output = Result<R::Response, AcpClientError>> + Send + use<R>
pub fn request<R: JsonRpcRequest>( &self, request: R, ) -> impl Future<Output = Result<R::Response, AcpClientError>> + Send + use<R>
Send immediately; polling the returned future only waits for the response.
pub fn resume_session( &self, request: ResumeSessionRequest, ) -> impl Future<Output = Result<ResumeSessionResponse, AcpClientError>> + Send + use<>
pub fn cancel( &self, request: CancelSessionNotification, ) -> Result<(), AcpClientError>
pub fn notify( &self, request: impl JsonRpcNotification, ) -> Result<(), AcpClientError>