pub fn format_embedded_resource(resource: &EmbeddedResource) -> StringExpand description
Formats an embedded resource as text for inclusion in agent context.
pub fn format_embedded_resource(resource: &EmbeddedResource) -> StringFormats an embedded resource as text for inclusion in agent context.