pub struct SubAgentState {
pub task_id: String,
pub agent_name: String,
pub done: bool,
pub tool_calls: Vec<SubAgentToolCall>,
}Expand description
Per-sub-agent state: tracks its tool calls in arrival order.
Fields
task_id: Stringagent_name: Stringdone: booltool_calls: Vec<SubAgentToolCall>Trait Implementations
Sourceimpl Clone for SubAgentState
impl Clone for SubAgentState
Sourceimpl Debug for SubAgentState
impl Debug for SubAgentState
impl Eq for SubAgentState
Sourceimpl JsonSchema for SubAgentState
impl JsonSchema for SubAgentState
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SubAgentState
impl PartialEq for SubAgentState
Sourceimpl Serialize for SubAgentState
impl Serialize for SubAgentState
impl StructuralPartialEq for SubAgentState