EnumSchema

Enum EnumSchema 

pub enum EnumSchema {
    Single(SingleSelectEnumSchema),
    Multi(MultiSelectEnumSchema),
    Legacy(LegacyEnumSchema),
}
Compliant with MCP 2025-06-18 specification for elicitation schemas. Enums must have string type for values and can optionally include human-readable names.

Example

use rmcp::model::*;

let enum_schema = EnumSchema::builder(vec!["US".to_string(), "UK".to_string()])
   .multiselect()
   .min_items(1u64).expect("Min items should be correct value")
   .max_items(4u64).expect("Max items should be correct value")
   .description("Country code")
   .build();

Variants

Implementations

Source

impl EnumSchema

pub fn builder(values: Vec<String>) -> EnumSchemaBuilder<SingleSelect>

Creates a new EnumSchemaBuilder with the given enum values.

This convenience method allows you to construct an enum schema by specifying the possible string values for the enum. Use the returned builder to further configure the schema before building it.

Arguments
  • values - A vector of strings representing the allowed enum values.
Example
use rmcp::model::*;

let enum_schema = EnumSchema::builder(vec!["A".to_string(), "B".to_string()]).
    with_default("A").
    expect("Default value should be valid").
    enum_titles(vec!["Option A".to_string(), "Option B".to_string()]).
    expect("Number of titles should match number of values").
    build();