pub enum McpNotification {
ServerStatus {
servers: Vec<McpServerStatusEntry>,
},
}Expand description
Server→client MCP extension notifications (relay → wisp).
Variants
ServerStatus
Fields

servers: Vec<McpServerStatusEntry>Trait Implementations
Sourceimpl Clone for McpNotification
impl Clone for McpNotification
Sourceimpl Debug for McpNotification
impl Debug for McpNotification
Sourceimpl<'de> Deserialize<'de> for McpNotification
impl<'de> Deserialize<'de> for McpNotification
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for McpNotification
Sourceimpl JsonRpcMessage for McpNotification
impl JsonRpcMessage for McpNotification
Sourcefn matches_method(__acp_method: &str) -> bool
fn matches_method(__acp_method: &str) -> bool
Check if this message type matches the given method name.
Sourcefn to_untyped_message(&self) -> Result<UntypedMessage, Error>
fn to_untyped_message(&self) -> Result<UntypedMessage, Error>
Convert this message into an untyped message.
impl JsonRpcNotification for McpNotificationwhere
Self: JsonRpcMessage,
Sourceimpl JsonSchema for McpNotification
impl JsonSchema for McpNotification
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for McpNotification
impl PartialEq for McpNotification
Sourceimpl Serialize for McpNotification
impl Serialize for McpNotification
impl StructuralPartialEq for McpNotification