pub struct ElicitationParams {
pub server_name: String,
pub request: CreateElicitationRequestParams,
}Expand description
Request parameters for the _aether/elicitation ext method.
Carries the full RMCP elicitation request plus the originating server name so the client can distinguish form vs URL mode and display which server is requesting.
Fields
server_name: Stringrequest: CreateElicitationRequestParamsTrait Implementations
Sourceimpl Clone for ElicitationParams
impl Clone for ElicitationParams
Sourcefn clone(&self) -> ElicitationParams
fn clone(&self) -> ElicitationParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ElicitationParams
impl Debug for ElicitationParams
Sourceimpl<'de> Deserialize<'de> for ElicitationParams
impl<'de> Deserialize<'de> for ElicitationParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonRpcMessage for ElicitationParams
impl JsonRpcMessage for ElicitationParams
Sourcefn matches_method(method: &str) -> bool
fn matches_method(method: &str) -> bool
Check if this message type matches the given method name.
Sourcefn to_untyped_message(&self) -> Result<UntypedMessage, Error>
fn to_untyped_message(&self) -> Result<UntypedMessage, Error>
Convert this message into an untyped message.
Sourceimpl JsonRpcRequest for ElicitationParams
impl JsonRpcRequest for ElicitationParams
Sourcetype Response = ElicitationResponse
type Response = ElicitationResponse
The type of data expected in response.
Sourceimpl PartialEq for ElicitationParams
impl PartialEq for ElicitationParams
Sourcefn eq(&self, other: &ElicitationParams) -> bool
fn eq(&self, other: &ElicitationParams) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ElicitationParams
impl Serialize for ElicitationParams
impl StructuralPartialEq for ElicitationParams