pub struct PromptSearchParams {
pub query: String,
pub limit: Option<usize>,
}Expand description
Parameters for the _aether/prompt_search request.
Fields
query: Stringlimit: Option<usize>Trait Implementations
Sourceimpl Clone for PromptSearchParams
impl Clone for PromptSearchParams
Sourcefn clone(&self) -> PromptSearchParams
fn clone(&self) -> PromptSearchParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PromptSearchParams
impl Debug for PromptSearchParams
Sourceimpl<'de> Deserialize<'de> for PromptSearchParams
impl<'de> Deserialize<'de> for PromptSearchParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonRpcMessage for PromptSearchParams
impl JsonRpcMessage for PromptSearchParams
Sourcefn matches_method(method: &str) -> bool
fn matches_method(method: &str) -> bool
Check if this message type matches the given method name.
Sourcefn to_untyped_message(&self) -> Result<UntypedMessage, Error>
fn to_untyped_message(&self) -> Result<UntypedMessage, Error>
Convert this message into an untyped message.
Sourceimpl JsonRpcRequest for PromptSearchParams
impl JsonRpcRequest for PromptSearchParams
Sourcetype Response = PromptSearchResponse
type Response = PromptSearchResponse
The type of data expected in response.
Sourceimpl PartialEq for PromptSearchParams
impl PartialEq for PromptSearchParams
Sourcefn eq(&self, other: &PromptSearchParams) -> bool
fn eq(&self, other: &PromptSearchParams) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PromptSearchParams
impl Serialize for PromptSearchParams
impl Eq for PromptSearchParams
impl StructuralPartialEq for PromptSearchParams