pub struct SubAgentProgressParams {
pub session_id: SessionId,
pub parent_tool_id: String,
pub task_id: String,
pub agent_name: String,
pub event: SubAgentEvent,
}Expand description
Parameters for _aether/sub_agent_progress notifications.
This is the wire format sent from the ACP server (aether-cli) to clients like wisp.
Fields
session_id: SessionIdparent_tool_id: Stringtask_id: Stringagent_name: Stringevent: SubAgentEventTrait Implementations
Sourceimpl Clone for SubAgentProgressParams
impl Clone for SubAgentProgressParams
Sourceimpl Debug for SubAgentProgressParams
impl Debug for SubAgentProgressParams
Sourceimpl<'de> Deserialize<'de> for SubAgentProgressParams
impl<'de> Deserialize<'de> for SubAgentProgressParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonRpcMessage for SubAgentProgressParams
impl JsonRpcMessage for SubAgentProgressParams
Sourcefn matches_method(__acp_method: &str) -> bool
fn matches_method(__acp_method: &str) -> bool
Check if this message type matches the given method name.
Sourcefn to_untyped_message(&self) -> Result<UntypedMessage, Error>
fn to_untyped_message(&self) -> Result<UntypedMessage, Error>
Convert this message into an untyped message.
impl JsonRpcNotification for SubAgentProgressParamswhere
Self: JsonRpcMessage,
Sourceimpl JsonSchema for SubAgentProgressParams
impl JsonSchema for SubAgentProgressParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SubAgentProgressParams
impl RefUnwindSafe for SubAgentProgressParams
impl Send for SubAgentProgressParams
impl Sync for SubAgentProgressParams
impl Unpin for SubAgentProgressParams
impl UnsafeUnpin for SubAgentProgressParams
impl UnwindSafe for SubAgentProgressParams