pub struct SubAgentToolCallUpdate {
pub id: String,
pub chunk: String,
}Fields
id: Stringchunk: StringTrait Implementations
Sourceimpl Clone for SubAgentToolCallUpdate
impl Clone for SubAgentToolCallUpdate
Sourceimpl Debug for SubAgentToolCallUpdate
impl Debug for SubAgentToolCallUpdate
Sourceimpl<'de> Deserialize<'de> for SubAgentToolCallUpdate
impl<'de> Deserialize<'de> for SubAgentToolCallUpdate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SubAgentToolCallUpdate
impl JsonSchema for SubAgentToolCallUpdate
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SubAgentToolCallUpdate
impl RefUnwindSafe for SubAgentToolCallUpdate
impl Send for SubAgentToolCallUpdate
impl Sync for SubAgentToolCallUpdate
impl Unpin for SubAgentToolCallUpdate
impl UnsafeUnpin for SubAgentToolCallUpdate
impl UnwindSafe for SubAgentToolCallUpdate