pub struct SubAgentToolError {
pub id: String,
pub name: String,
}Fields
id: Stringname: StringTrait Implementations
Sourceimpl Clone for SubAgentToolError
impl Clone for SubAgentToolError
Sourceimpl Debug for SubAgentToolError
impl Debug for SubAgentToolError
Sourceimpl<'de> Deserialize<'de> for SubAgentToolError
impl<'de> Deserialize<'de> for SubAgentToolError
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SubAgentToolError
impl JsonSchema for SubAgentToolError
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SubAgentToolError
impl RefUnwindSafe for SubAgentToolError
impl Send for SubAgentToolError
impl Sync for SubAgentToolError
impl Unpin for SubAgentToolError
impl UnsafeUnpin for SubAgentToolError
impl UnwindSafe for SubAgentToolError