pub struct SubAgentToolRequest {
pub id: String,
pub name: String,
pub arguments: String,
}Fields
id: Stringname: Stringarguments: StringTrait Implementations
Sourceimpl Clone for SubAgentToolRequest
impl Clone for SubAgentToolRequest
Sourceimpl Debug for SubAgentToolRequest
impl Debug for SubAgentToolRequest
Sourceimpl<'de> Deserialize<'de> for SubAgentToolRequest
impl<'de> Deserialize<'de> for SubAgentToolRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SubAgentToolRequest
impl JsonSchema for SubAgentToolRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SubAgentToolRequest
impl RefUnwindSafe for SubAgentToolRequest
impl Send for SubAgentToolRequest
impl Sync for SubAgentToolRequest
impl Unpin for SubAgentToolRequest
impl UnsafeUnpin for SubAgentToolRequest
impl UnwindSafe for SubAgentToolRequest