pub struct WorkspaceListParams {
pub session_id: String,
}Expand description
Parameters for the _aether/workspace_list request.
Fields
session_id: StringTrait Implementations
Sourceimpl Clone for WorkspaceListParams
impl Clone for WorkspaceListParams
Sourcefn clone(&self) -> WorkspaceListParams
fn clone(&self) -> WorkspaceListParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkspaceListParams
impl Debug for WorkspaceListParams
Sourceimpl<'de> Deserialize<'de> for WorkspaceListParams
impl<'de> Deserialize<'de> for WorkspaceListParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for WorkspaceListParams
Sourceimpl JsonRpcMessage for WorkspaceListParams
impl JsonRpcMessage for WorkspaceListParams
Sourcefn matches_method(method: &str) -> bool
fn matches_method(method: &str) -> bool
Check if this message type matches the given method name.
Sourcefn to_untyped_message(&self) -> Result<UntypedMessage, Error>
fn to_untyped_message(&self) -> Result<UntypedMessage, Error>
Convert this message into an untyped message.
Sourceimpl JsonRpcRequest for WorkspaceListParams
impl JsonRpcRequest for WorkspaceListParams
Sourcetype Response = WorkspaceListResponse
type Response = WorkspaceListResponse
The type of data expected in response.
Sourceimpl PartialEq for WorkspaceListParams
impl PartialEq for WorkspaceListParams
Sourcefn eq(&self, other: &WorkspaceListParams) -> bool
fn eq(&self, other: &WorkspaceListParams) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for WorkspaceListParams
impl Serialize for WorkspaceListParams
impl StructuralPartialEq for WorkspaceListParams