pub struct WorkspaceListResponse {
pub workspaces: Vec<WorkspaceEntry>,
}Expand description
Response for the _aether/workspace_list request: every managed workspace
originating from the same git repository as the session’s working directory.
Fields
workspaces: Vec<WorkspaceEntry>Trait Implementations
Sourceimpl Clone for WorkspaceListResponse
impl Clone for WorkspaceListResponse
Sourcefn clone(&self) -> WorkspaceListResponse
fn clone(&self) -> WorkspaceListResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkspaceListResponse
impl Debug for WorkspaceListResponse
Sourceimpl<'de> Deserialize<'de> for WorkspaceListResponse
impl<'de> Deserialize<'de> for WorkspaceListResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for WorkspaceListResponse
Sourceimpl PartialEq for WorkspaceListResponse
impl PartialEq for WorkspaceListResponse
Sourcefn eq(&self, other: &WorkspaceListResponse) -> bool
fn eq(&self, other: &WorkspaceListResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for WorkspaceListResponse
impl Serialize for WorkspaceListResponse
impl StructuralPartialEq for WorkspaceListResponse