pub struct WorkspaceMoveParams {
pub session_id: String,
pub target: WorkspaceMoveTarget,
}Expand description
Parameters for the _aether/workspace_move request.
Fields
session_id: Stringtarget: WorkspaceMoveTargetTrait Implementations
Sourceimpl Clone for WorkspaceMoveParams
impl Clone for WorkspaceMoveParams
Sourcefn clone(&self) -> WorkspaceMoveParams
fn clone(&self) -> WorkspaceMoveParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkspaceMoveParams
impl Debug for WorkspaceMoveParams
Sourceimpl<'de> Deserialize<'de> for WorkspaceMoveParams
impl<'de> Deserialize<'de> for WorkspaceMoveParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for WorkspaceMoveParams
Sourceimpl JsonRpcMessage for WorkspaceMoveParams
impl JsonRpcMessage for WorkspaceMoveParams
Sourcefn matches_method(method: &str) -> bool
fn matches_method(method: &str) -> bool
Check if this message type matches the given method name.
Sourcefn to_untyped_message(&self) -> Result<UntypedMessage, Error>
fn to_untyped_message(&self) -> Result<UntypedMessage, Error>
Convert this message into an untyped message.
Sourceimpl JsonRpcRequest for WorkspaceMoveParams
impl JsonRpcRequest for WorkspaceMoveParams
Sourcetype Response = WorkspaceMoveResponse
type Response = WorkspaceMoveResponse
The type of data expected in response.
Sourceimpl PartialEq for WorkspaceMoveParams
impl PartialEq for WorkspaceMoveParams
Sourcefn eq(&self, other: &WorkspaceMoveParams) -> bool
fn eq(&self, other: &WorkspaceMoveParams) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for WorkspaceMoveParams
impl Serialize for WorkspaceMoveParams
impl StructuralPartialEq for WorkspaceMoveParams