Module testing

Module testing 

In-memory test harness for ACP connections.

Structs

CaptureConnection
Channel
A channel endpoint representing one side of a bidirectional JSON-RPC transport.
ConnectedPair
FakeAgent
FakeAgentRequests
TestPeer

Functions

connect_pair
idle_notification
Foreground work is idle, optionally with a reported stop reason.
initialize_request
Initialization request from an in-memory v2 client.
initialize_response
Initialization response from an in-memory v2 agent.
plan_notification
Replace the entries of an agent-owned plan.
running_notification
A live foreground turn has started.
test_connection
Build a live ConnectionTo<Client> over an in-memory duplex transport with a peer on the other end. Must be called inside a LocalSet.