Skip to main contentModule client
Source - AcpClient
- An initialized ACP connection that can create and manage multiple sessions.
- AcpClientHandle
- A cloneable handle for issuing typed lifecycle requests and prompt commands.
- LoadedSession
- The result of loading an ACP session, including notifications sent before the response.
- TokioAcpAgent
- AcpClientError
- Errors returned by ACP client-side operations.
- AcpEvent
- Events forwarded from the ACP connection to the main event loop.
- connect_acp_client
- Connect to an ACP agent and complete initialization without creating a session.