Structs
- AcpPrompt
Handle - Send-safe handle for issuing prompt commands to the ACP client task.
- AcpSession
- ACP session with all handles needed by the caller.
Enums
- AcpClient
Error - Errors returned by ACP client-side operations.
- AcpEvent
- Events forwarded from the ACP connection to the main event loop.
- Prompt
Command - Commands sent from the main thread to the ACP client task.
Functions
- spawn_
acp_ session - Spawn an agent subprocess and establish an ACP session.