Skip to main contentModule client
Source - AcpPromptHandle
- Send-safe handle for issuing prompt commands to the !Send ACP connection.
- AcpSession
- ACP session with all handles needed by the caller.
- AutoApproveClient
- A built-in ACP client that auto-approves permissions and forwards session
notifications as
AcpEvents.
- AcpClientError
- Errors returned by ACP client-side operations.
- AcpEvent
- Events forwarded from the ACP connection to the main event loop.
- PromptCommand
- Commands sent from the main thread to the ACP
LocalSet thread.
- spawn_acp_session
- Spawn an agent subprocess and establish an ACP session.