pub struct AcpClientHandle { /* private fields */ }Expand description
A cloneable handle for issuing typed lifecycle requests and prompt commands.
Implementations
Sourceimpl AcpClientHandle
impl AcpClientHandle
pub fn detached() -> Self
pub async fn prompt( &self, request: PromptRequest, ) -> Result<PromptResponse, AcpClientError>
Sourcepub async fn load_session(
&self,
request: LoadSessionRequest,
) -> Result<LoadedSession, AcpClientError>
pub async fn load_session( &self, request: LoadSessionRequest, ) -> Result<LoadedSession, AcpClientError>
Load a session and collect its replay notifications in wire order.
pub async fn new_session( &self, request: NewSessionRequest, ) -> Result<NewSessionResponse, AcpClientError>
pub async fn list_sessions( &self, request: ListSessionsRequest, ) -> Result<ListSessionsResponse, AcpClientError>
Sourcepub async fn resume_session(
&self,
request: ResumeSessionRequest,
) -> Result<ResumeSessionResponse, AcpClientError>
pub async fn resume_session( &self, request: ResumeSessionRequest, ) -> Result<ResumeSessionResponse, AcpClientError>
Resume a session without collecting or replaying its prior notifications.
pub async fn close_session( &self, request: CloseSessionRequest, ) -> Result<CloseSessionResponse, AcpClientError>
Sourcepub async fn search_prompts(
&self,
params: PromptSearchParams,
) -> Result<PromptSearchResponse, AcpClientError>
pub async fn search_prompts( &self, params: PromptSearchParams, ) -> Result<PromptSearchResponse, AcpClientError>
Search the agent’s prompt history through Aether’s ACP extension.
Sourcepub async fn preview_session(
&self,
params: SessionPreviewParams,
) -> Result<SessionPreviewResponse, AcpClientError>
pub async fn preview_session( &self, params: SessionPreviewParams, ) -> Result<SessionPreviewResponse, AcpClientError>
Load a session preview through Aether’s ACP extension.
Sourcepub async fn list_workspaces(
&self,
params: WorkspaceListParams,
) -> Result<WorkspaceListResponse, AcpClientError>
pub async fn list_workspaces( &self, params: WorkspaceListParams, ) -> Result<WorkspaceListResponse, AcpClientError>
List workspaces through Aether’s ACP extension.
Sourcepub async fn move_workspace(
&self,
params: WorkspaceMoveParams,
) -> Result<WorkspaceMoveResponse, AcpClientError>
pub async fn move_workspace( &self, params: WorkspaceMoveParams, ) -> Result<WorkspaceMoveResponse, AcpClientError>
Move a session through Aether’s ACP extension.
pub async fn set_config_option( &self, request: SetSessionConfigOptionRequest, ) -> Result<SetSessionConfigOptionResponse, AcpClientError>
pub async fn authenticate( &self, request: AuthenticateRequest, ) -> Result<AuthenticateResponse, AcpClientError>
pub async fn cancel( &self, request: CancelNotification, ) -> Result<(), AcpClientError>
pub async fn authenticate_mcp_server( &self, request: McpRequest, ) -> Result<(), AcpClientError>